@@ -12,13 +12,12 @@
 ## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 ## GNU General Public License for more details.
 
-import sys
+
 import subprocess
-import mktxp.cli.checks.chk_pv
-from mktxp.utils.utils import run_cmd
+from mktxp.cli.config.config import config_handler
 from mktxp.cli.options import MKTXPOptionsParser, MKTXPCommands
-from mktxp.cli.config.config import config_handler, ConfigEntry
-from mktxp.basep import MKTXPProcessor, MKTXPCLIProcessor
+from mktxp.processor.mktxp import MKTXPProcessor, MKTXPCLIProcessor
+
 
 class MKTXPDispatcher:
     ''' Base MKTXP Commands Dispatcher
@@ -36,21 +35,15 @@ class MKTXPDispatcher:
         elif args['sub_cmd'] == MKTXPCommands.SHOW:
             self.show_entries(args)
 
-        elif args['sub_cmd'] == MKTXPCommands.ADD:
-            self.add_entry(args)
-
-        elif args['sub_cmd'] == MKTXPCommands.EDIT:
-            self.edit_entry(args)
-
-        elif args['sub_cmd'] == MKTXPCommands.DELETE:
-            self.delete_entry(args)
-
         elif args['sub_cmd'] == MKTXPCommands.EXPORT:
             self.start_export(args)
 
         elif args['sub_cmd'] == MKTXPCommands.PRINT:
             self.print(args)
 
+        elif args['sub_cmd'] == MKTXPCommands.EDIT:
+            self.edit_entry(args)
+
         else:
             # nothing to dispatch
             return False
@@ -84,10 +77,6 @@ class MKTXPDispatcher:
                         print(f'    {field}: {getattr(entry, field)}')
                 print('\n')
 
-    def add_entry(self, args):
-        entry_args = {key: value for key, value in args.items() if key not in set(['sub_cmd', 'entry_name'])}
-        config_handler.register_entry(entry_name = args['entry_name'], entry_args = entry_args)
-
     def edit_entry(self, args):        
         editor = args['editor']
         if not editor:
@@ -96,16 +85,13 @@ class MKTXPDispatcher:
             subprocess.check_call([editor, config_handler.mktxp_conf_path])
         else:
             subprocess.check_call([editor, config_handler.usr_conf_data_path])
-
-    def delete_entry(self, args):
-        config_handler.unregister_entry(entry_name = args['entry_name'])
-        
+       
     def start_export(self, args):
         MKTXPProcessor.start()
 
     def print(self, args):
         if not (args['wifi_clients'] or args['capsman_clients']):
-            print("Select metric option(s) to print out, or run 'mktxp print' -h to find out more")
+            print("Select metric option(s) to print out, or run 'mktxp print -h' to find out more")
 
         if args['wifi_clients']:
             MKTXPCLIProcessor.wifi_clients(args['entry_name'])
@@ -113,6 +99,9 @@ class MKTXPDispatcher:
         if args['capsman_clients']:
             MKTXPCLIProcessor.capsman_clients(args['entry_name'])
 
+        if args['dhcp_clients']:
+            MKTXPCLIProcessor.dhcp_clients(args['entry_name'])
+            
 
 def main():
     MKTXPDispatcher().dispatch()
